# 自定义规则

> [!NOTE]
> 下文的「消息会话来源」指的是 UMO。一个 UMO 唯一指定了一个消息平台下的具体的某个会话。

在 v4.7.0 版本之后，我们重构了 AstrBot 原来的「会话管理」功能为「自定义规则」功能。以减少和配置文件的冲突。

你可以把自定义规则理解为对指定消息来源更加灵活的自定义强制处理规则，其优先级高于配置文件。

例如，原本一个消息平台使用配置文件 “default”，这个消息平台下的所有会话都按照配置文件中的规则进行处理。如果你希望对某个会话来源 A 进行特殊处理，在原来，你需要单独创建一个配置文件，然后将 A 绑定到这个配置文件中。而现在，你只需要在 WebUI 的自定义规则页中创建一个自定义规则，然后选择消息来源 A 即可。你可以定义如下规则：

1. 是否启用该消息会话来源的消息处理。如果不启用，其效果相当于将该消息会话来源拉入黑名单。
2. 是否对该消息会话来源的消息启用 LLM。如果不启用，则不会使用 AI 能力。
3. 是否对该消息会话来源的消息启用 TTS。如果不启用，则不会使用 TTS 能力。
4. 对该消息会话来源配置特定的聊天模型、语音识别模型（STT）、语音合成模型（TTS）。
5. 对该消息会话来源配置特定的人格。